==> piwigo-2.1.3.zip: piwigo/plugins/LocalFilesEditor/language/de_DE/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Lokale Konfiguration';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Vorlagen';
$lang['locfiledit_onglet_lang'] = 'Sprachen';
$lang['locfiledit_onglet_plug'] = 'Persönliche Plugin';
$lang['locfiledit_cant_save'] = 'Aktuelle Datei ist nicht überschreibbar. Prüfen Sie ob Schreibrechte für das Verzeichnis "include/" bestehen (chmod)';
$lang['locfiledit_newfile'] = 'Die Datei ist nicht vorhanden und wird erstellt vom Localfiles Editor';
$lang['locfiledit_save_config'] = 'Datei erfolgreich geschrieben.';
$lang['locfiledit_show_default'] = 'Zeige Referenz-Datei: ';
$lang['locfiledit_save_bak'] = 'Backup-Kopie wird beim Speichern erstellt.';
$lang['locfiledit_saved_bak'] = 'Backup-Datei erstellt (%s)';
$lang['locfiledit_save_file'] = 'Datei speichern';
$lang['locfiledit_choose_file'] = 'Wählen Sie eine Datei zum bearbeiten aus';
$lang['locfiledit_edit'] = 'Bearbeiten';
$lang['locfiledit_restore'] = 'Wiederherstellung der Backup-Datei';
$lang['locfiledit_restore_confirm'] = 'Bitte bestätigen?
Wiederherstellung wird nicht wirksam sein bis zum nächsten speichern.';
$lang['locfiledit_bak_loaded1'] = 'Backup-Datei geladen.';
$lang['locfiledit_bak_loaded2'] = 'Sie müssen die Datei speichern um sie wiederherstellen zu können.';
$lang['locfiledit_syntax_error'] = 'Syntax-Fehler! Datei kann nicht gespeichert werden.';
$lang['locfiledit_enable_editarea'] = 'Aktiviere den Bearbeitungsbereich';
$lang['locfiledit_disable_editarea'] = 'Deaktiviere den Bearbeitungsbereich';
$lang['locfiledit_new_tpl'] = 'Erstelle eine neue Datei';
$lang['locfiledit_new_filename'] = 'Dateiname';
$lang['locfiledit_model'] = 'Modell';
$lang['locfiledit_empty_page'] = 'Leere Seite';
$lang['locfiledit_parent_directory'] = 'Übergeordnetes Verzeichnis';
$lang['locfiledit_filename_error'] = 'Verbotene Zeichen im Dateinamen.';
$lang['locfiledit_file_already_exists'] = 'Datei ist bereits vorhanden.';
$lang['locfiledit_model_error'] = 'Sie müssen ein Modell wählen.';
$lang['locfiledit_empty_filename'] = 'Sie müssen einen Dateiname eingeben.';
/* TODO */ $lang['locfiledit_webmaster_only'] = 'Only webmasters can create or modify local files.';

?>

==> piwigo-2.1.6.zip: piwigo/plugins/LocalFilesEditor/language/de_DE/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Lokale Konfiguration';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Vorlagen';
$lang['locfiledit_onglet_lang'] = 'Sprachen';
$lang['locfiledit_onglet_plug'] = 'Persönliche Plugin';
$lang['locfiledit_cant_save'] = 'Aktuelle Datei ist nicht überschreibbar. Prüfen Sie ob Schreibrechte für das Verzeichnis "local/" bestehen (chmod)';
$lang['locfiledit_newfile'] = 'Die Datei ist nicht vorhanden und wird erstellt vom Localfiles Editor';
$lang['locfiledit_save_config'] = 'Datei erfolgreich geschrieben.';
$lang['locfiledit_show_default'] = 'Zeige Referenz-Datei: ';
$lang['locfiledit_save_bak'] = 'Backup-Kopie wird beim Speichern erstellt.';
$lang['locfiledit_saved_bak'] = 'Backup-Datei erstellt (%s)';
$lang['locfiledit_save_file'] = 'Datei speichern';
$lang['locfiledit_choose_file'] = 'Wählen Sie eine Datei zum bearbeiten aus';
$lang['locfiledit_edit'] = 'Bearbeiten';
$lang['locfiledit_restore'] = 'Wiederherstellung der Backup-Datei';
$lang['locfiledit_restore_confirm'] = 'Bitte bestätigen?
Wiederherstellung wird nicht wirksam sein bis zum nächsten speichern.';
$lang['locfiledit_bak_loaded1'] = 'Backup-Datei geladen.';
$lang['locfiledit_bak_loaded2'] = 'Sie müssen die Datei speichern um sie wiederherstellen zu können.';
$lang['locfiledit_syntax_error'] = 'Syntax-Fehler! Datei kann nicht gespeichert werden.';
$lang['locfiledit_enable_editarea'] = 'Aktiviere den Bearbeitungsbereich';
$lang['locfiledit_disable_editarea'] = 'Deaktiviere den Bearbeitungsbereich';
$lang['locfiledit_new_tpl'] = 'Erstelle eine neue Datei';
$lang['locfiledit_new_filename'] = 'Dateiname';
$lang['locfiledit_model'] = 'Modell';
$lang['locfiledit_empty_page'] = 'Leere Seite';
$lang['locfiledit_parent_directory'] = 'Übergeordnetes Verzeichnis';
$lang['locfiledit_filename_error'] = 'Verbotene Zeichen im Dateinamen.';
$lang['locfiledit_file_already_exists'] = 'Datei ist bereits vorhanden.';
$lang['locfiledit_model_error'] = 'Sie müssen ein Modell wählen.';
$lang['locfiledit_empty_filename'] = 'Sie müssen einen Dateiname eingeben.';
/* TODO */ $lang['locfiledit_webmaster_only'] = 'Only webmasters can create or modify local files.';

?>
